@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Test::CheckDeps;
 {
-  $Dist::Zilla::Plugin::Test::CheckDeps::VERSION = '0.006';
+  $Dist::Zilla::Plugin::Test::CheckDeps::VERSION = '0.007';
 }
 
 use Moose;
@@ -13,19 +13,32 @@ has fatal => (
 	default => 0,
 );
 
+has level => (
+        is => 'ro',
+        isa => 'Str',
+        lazy => 1,
+        default => 'classic',
+);
+
+
 around add_file => sub {
 	my ($orig, $self, $file) = @_;
+
 	return $self->$orig(
 		Dist::Zilla::File::InMemory->new(
 			name    => $file->name,
-			content => $self->fill_in_string($file->content, { fatal => $self->fatal })
+			content => $self->fill_in_string($file->content,
+                                         {
+                                                fatal => $self->fatal,
+                                                level => $self->level,
+                                         })
 		)
 	);
 };
 
 sub register_prereqs {
 	my $self = shift;
-	$self->zilla->register_prereqs({ phase => 'test' }, 'Test::More' => 0.88, 'Test::CheckDeps' => 0.002);
+	$self->zilla->register_prereqs({ phase => 'test' }, 'Test::More' => 0.94, 'Test::CheckDeps' => 0.006);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -33,6 +46,8 @@ no Moose;
 
 1;
 
+#ABSTRACT: Check for presence of dependencies
+
 =pod
 
 =head1 NAME
@@ -41,7 +56,25 @@ Dist::Zilla::Plugin::Test::CheckDeps - Check for presence of dependencies
 
 =head1 VERSION
 
-version 0.006
+version 0.007
+
+=head1 SYNOPSIS
+
+ [Test::CheckDeps]
+ fatal = 0          ; default
+ level = classic
+
+=head1 DESCRIPTION
+
+This module adds a test that assures all dependencies have been installed properly. If requested, it can bail out all testing on error.
+
+If C<fatal> is true, C<BAIL_OUT> is called if the tests fail.
+
+C<level> is passed to C<check_dependencies> in L<Test::CheckDeps>.
+(Defaults to C<'classic'>.)
+
+=for Pod::Coverage register_prereqs
+=end
 
 =head1 AUTHOR
 
@@ -59,9 +92,9 @@ the same terms as the Perl 5 programming language system itself.
 __DATA__
 ___[ t/00-check-deps.t ]___
 use Test::More 0.94;
-use Test::CheckDeps;
+use Test::CheckDeps 0.004;
 
-check_dependencies();
+check_dependencies('{{ $level }}');
 
 if ({{ $fatal }}) {
     BAIL_OUT("Missing dependencies") if !Test::More->builder->is_passing;
@@ -69,22 +102,3 @@ if ({{ $fatal }}) {
 
 done_testing;
 
-__END__
-
-#ABSTRACT: Check for presence of dependencies
-
-=head1 SYNOPSIS
-
- [Test::CheckDeps]
- fatal = 0 ; default
-
-=head1 DESCRIPTION
-
-This module adds a test that assures all dependencies have been installed properly. If requested, it can bail out all testing on error.
-
-__END__
-
-=for Pod::Coverage
-register_prereqs
-=end
-
